You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@harmony.apache.org by hi...@apache.org on 2007/10/24 21:12:25 UTC

svn commit: r587970 - in /harmony/enhanced/classlib/trunk/modules/jndi/src/test/java/org/apache/harmony/jndi/tests/javax/naming: ldap/ ldap/extras/ ldap/whitebox/ spi/mock/ldap/

Author: hindessm
Date: Wed Oct 24 12:12:24 2007
New Revision: 587970

URL: http://svn.apache.org/viewvc?rev=587970&view=rev
Log:
Spelling fixes and replacing 'gonna' with the less colloquial 'going to'.

Modified:
    harmony/enhanced/classlib/trunk/modules/jndi/src/test/java/org/apache/harmony/jndi/tests/javax/naming/ldap/ControlFactoryTest.java
    harmony/enhanced/classlib/trunk/modules/jndi/src/test/java/org/apache/harmony/jndi/tests/javax/naming/ldap/RdnTest.java
    harmony/enhanced/classlib/trunk/modules/jndi/src/test/java/org/apache/harmony/jndi/tests/javax/naming/ldap/StartTlsRequestTest.java
    harmony/enhanced/classlib/trunk/modules/jndi/src/test/java/org/apache/harmony/jndi/tests/javax/naming/ldap/TestPagedResultsControls.java
    harmony/enhanced/classlib/trunk/modules/jndi/src/test/java/org/apache/harmony/jndi/tests/javax/naming/ldap/TestPagedResultsResponseControl.java
    harmony/enhanced/classlib/trunk/modules/jndi/src/test/java/org/apache/harmony/jndi/tests/javax/naming/ldap/extras/TestRdnParser.java
    harmony/enhanced/classlib/trunk/modules/jndi/src/test/java/org/apache/harmony/jndi/tests/javax/naming/ldap/whitebox/TestControlFactoryWhiteBoxDevelopment.java
    harmony/enhanced/classlib/trunk/modules/jndi/src/test/java/org/apache/harmony/jndi/tests/javax/naming/ldap/whitebox/TestInitialLdapContextWhiteBoxDevelopment.java
    harmony/enhanced/classlib/trunk/modules/jndi/src/test/java/org/apache/harmony/jndi/tests/javax/naming/ldap/whitebox/TestLdapNameWhiteBoxDevelopment.java
    harmony/enhanced/classlib/trunk/modules/jndi/src/test/java/org/apache/harmony/jndi/tests/javax/naming/ldap/whitebox/TestLdapReferralException.java
    harmony/enhanced/classlib/trunk/modules/jndi/src/test/java/org/apache/harmony/jndi/tests/javax/naming/ldap/whitebox/TestRdnWhiteBoxDevelopment.java
    harmony/enhanced/classlib/trunk/modules/jndi/src/test/java/org/apache/harmony/jndi/tests/javax/naming/spi/mock/ldap/MockInitialLdapContext.java
    harmony/enhanced/classlib/trunk/modules/jndi/src/test/java/org/apache/harmony/jndi/tests/javax/naming/spi/mock/ldap/MockUnsolicitedNotification.java

Modified: harmony/enhanced/classlib/trunk/modules/jndi/src/test/java/org/apache/harmony/jndi/tests/javax/naming/ldap/ControlFactoryTest.java
URL: http://svn.apache.org/viewvc/harmony/enhanced/classlib/trunk/modules/jndi/src/test/java/org/apache/harmony/jndi/tests/javax/naming/ldap/ControlFactoryTest.java?rev=587970&r1=587969&r2=587970&view=diff
==============================================================================
--- harmony/enhanced/classlib/trunk/modules/jndi/src/test/java/org/apache/harmony/jndi/tests/javax/naming/ldap/ControlFactoryTest.java (original)
+++ harmony/enhanced/classlib/trunk/modules/jndi/src/test/java/org/apache/harmony/jndi/tests/javax/naming/ldap/ControlFactoryTest.java Wed Oct 24 12:12:24 2007
@@ -29,7 +29,7 @@
 
 /**
  * <p>This Test class is testing the class ControlFactory in the javax.naming.ldap package.</p>
- * <p>Here in the next tables we are gonna find all methods to be tested:</p>
+ * <p>Here in the next tables we are going to find all methods to be tested:</p>
  * <table>
  	<tbody><th>Method Summary:</th>
 	<tr><TD>Return</TD><TD>Method</TD></tr>

Modified: harmony/enhanced/classlib/trunk/modules/jndi/src/test/java/org/apache/harmony/jndi/tests/javax/naming/ldap/RdnTest.java
URL: http://svn.apache.org/viewvc/harmony/enhanced/classlib/trunk/modules/jndi/src/test/java/org/apache/harmony/jndi/tests/javax/naming/ldap/RdnTest.java?rev=587970&r1=587969&r2=587970&view=diff
==============================================================================
--- harmony/enhanced/classlib/trunk/modules/jndi/src/test/java/org/apache/harmony/jndi/tests/javax/naming/ldap/RdnTest.java (original)
+++ harmony/enhanced/classlib/trunk/modules/jndi/src/test/java/org/apache/harmony/jndi/tests/javax/naming/ldap/RdnTest.java Wed Oct 24 12:12:24 2007
@@ -665,10 +665,10 @@
      * </p>
      * <p>
      * This is a test for the constructor of the class Rdn. Here we are testing
-     * with a non-empty String and diferents objects.
+     * with a non-empty String and different objects.
      * </p>
      * <p>
-     * The expected result is an instance of the class with the diferents
+     * The expected result is an instance of the class with the different
      * arguments because the arguments are not parsed.
      * </p>
      */

Modified: harmony/enhanced/classlib/trunk/modules/jndi/src/test/java/org/apache/harmony/jndi/tests/javax/naming/ldap/StartTlsRequestTest.java
URL: http://svn.apache.org/viewvc/harmony/enhanced/classlib/trunk/modules/jndi/src/test/java/org/apache/harmony/jndi/tests/javax/naming/ldap/StartTlsRequestTest.java?rev=587970&r1=587969&r2=587970&view=diff
==============================================================================
--- harmony/enhanced/classlib/trunk/modules/jndi/src/test/java/org/apache/harmony/jndi/tests/javax/naming/ldap/StartTlsRequestTest.java (original)
+++ harmony/enhanced/classlib/trunk/modules/jndi/src/test/java/org/apache/harmony/jndi/tests/javax/naming/ldap/StartTlsRequestTest.java Wed Oct 24 12:12:24 2007
@@ -29,7 +29,7 @@
 import org.apache.harmony.jndi.tests.javax.naming.spi.mock.ldap.MockStartTlsResponse;
 /**
  * <p>This Test class is testing the class StartTlsRequest in the javax.naming.ldap package.</p>
- * <p>Here in the next tables we are gonna find all methods to be tested:</p>
+ * <p>Here in the next tables we are going to find all methods to be tested:</p>
  *  <table class="t" cellspacing="0">
 	<tbody><th>Constructors:</th>
 		<tr>

Modified: harmony/enhanced/classlib/trunk/modules/jndi/src/test/java/org/apache/harmony/jndi/tests/javax/naming/ldap/TestPagedResultsControls.java
URL: http://svn.apache.org/viewvc/harmony/enhanced/classlib/trunk/modules/jndi/src/test/java/org/apache/harmony/jndi/tests/javax/naming/ldap/TestPagedResultsControls.java?rev=587970&r1=587969&r2=587970&view=diff
==============================================================================
--- harmony/enhanced/classlib/trunk/modules/jndi/src/test/java/org/apache/harmony/jndi/tests/javax/naming/ldap/TestPagedResultsControls.java (original)
+++ harmony/enhanced/classlib/trunk/modules/jndi/src/test/java/org/apache/harmony/jndi/tests/javax/naming/ldap/TestPagedResultsControls.java Wed Oct 24 12:12:24 2007
@@ -29,7 +29,7 @@
 
 /**        
  * <p>This Test class is testing the PagedResultsControls class.</p>
- * <p>In the next tables we are gonna see the methods that we test in this class:</p>
+ * <p>In the next tables we are going to see the methods that we test in this class:</p>
  * <table class="t" cellspacing="0">
 	<tbody><th>Constructors:</th>
 		<tr>

Modified: harmony/enhanced/classlib/trunk/modules/jndi/src/test/java/org/apache/harmony/jndi/tests/javax/naming/ldap/TestPagedResultsResponseControl.java
URL: http://svn.apache.org/viewvc/harmony/enhanced/classlib/trunk/modules/jndi/src/test/java/org/apache/harmony/jndi/tests/javax/naming/ldap/TestPagedResultsResponseControl.java?rev=587970&r1=587969&r2=587970&view=diff
==============================================================================
--- harmony/enhanced/classlib/trunk/modules/jndi/src/test/java/org/apache/harmony/jndi/tests/javax/naming/ldap/TestPagedResultsResponseControl.java (original)
+++ harmony/enhanced/classlib/trunk/modules/jndi/src/test/java/org/apache/harmony/jndi/tests/javax/naming/ldap/TestPagedResultsResponseControl.java Wed Oct 24 12:12:24 2007
@@ -32,7 +32,7 @@
 
 /**        
  * <p>This Test class is testing the PagedResultsControls class.</p>
- * <p>In the next tables we are gonna see the methods that we test in this class:</p>
+ * <p>In the next tables we are going to see the methods that we test in this class:</p>
  * <table class="t" cellspacing="0">
 	<tbody><th>Constructors:</th>
 		<tr>

Modified: harmony/enhanced/classlib/trunk/modules/jndi/src/test/java/org/apache/harmony/jndi/tests/javax/naming/ldap/extras/TestRdnParser.java
URL: http://svn.apache.org/viewvc/harmony/enhanced/classlib/trunk/modules/jndi/src/test/java/org/apache/harmony/jndi/tests/javax/naming/ldap/extras/TestRdnParser.java?rev=587970&r1=587969&r2=587970&view=diff
==============================================================================
--- harmony/enhanced/classlib/trunk/modules/jndi/src/test/java/org/apache/harmony/jndi/tests/javax/naming/ldap/extras/TestRdnParser.java (original)
+++ harmony/enhanced/classlib/trunk/modules/jndi/src/test/java/org/apache/harmony/jndi/tests/javax/naming/ldap/extras/TestRdnParser.java Wed Oct 24 12:12:24 2007
@@ -27,7 +27,7 @@
 import junit.framework.TestCase;
 
 /**
- * <p>Test case to test the class Rdn when it recives an UTF-8 string that happens when is escaped with the 
+ * <p>Test case to test the class Rdn when it receives an UTF-8 string that happens when is escaped with the 
  * blackslash ('\' ASCII 92).</p>
  *
  */
@@ -293,7 +293,7 @@
 	}
 
 	/**
-	 * <p>Here we are testing if the constructor can create an instance of the rdn with diferents combiantions of utf8 not printables.</p>
+	 * <p>Here we are testing if the constructor can create an instance of the rdn with different combinations of utf8 not printables.</p>
 	 *
 	 */
 	public void testRdnString001() {
@@ -310,7 +310,7 @@
 	}
 
 	/**
-	 * <p>Here we are testing if the constructor can create an instance of the rdn with diferents combiantions of utf8 printables.</p>
+	 * <p>Here we are testing if the constructor can create an instance of the rdn with different combinations of utf8 printables.</p>
 	 *
 	 */
 	public void testRdnString002() {
@@ -329,7 +329,7 @@
 	}
 
 	/**
-	 * <p>Here we are testing if the constructor can create an instance of the rdn with diferents combiantions of utf8 not printables and 
+	 * <p>Here we are testing if the constructor can create an instance of the rdn with different combinations of utf8 not printables and 
 	 * printables. 1 to 1</p>
 	 *
 	 */
@@ -352,7 +352,7 @@
 	}
 
 	/**
-	 * <p>Here we are testing if the constructor can create an instance of the rdn with diferents combiantions of utf8 not printables and 
+	 * <p>Here we are testing if the constructor can create an instance of the rdn with different combinations of utf8 not printables and 
 	 * printables. 1 to 1</p>
 	 *
 	 */	
@@ -375,7 +375,7 @@
 	}
 
 	/**
-	 * <p>Here we are testing if the constructor can create an instance of the rdn with diferents combiantions of utf8 not printables and 
+	 * <p>Here we are testing if the constructor can create an instance of the rdn with different combinations of utf8 not printables and 
 	 * printables. 1 utf8 to 1 ascii to 1 utf8 and 1 ascii to 1 utf8 to 1 ascii.</p>
 	 *
 	 */	
@@ -517,7 +517,7 @@
 	}
 	
 	/**
-	 * <p>Here we are testing if the constructor recives in the value an utf8 value.</p>
+	 * <p>Here we are testing if the constructor receives in the value an utf8 value.</p>
 	 *
 	 */
 	public void testRdnString010(){
@@ -535,7 +535,7 @@
 	}
 	
 	/**
-	 * <p>Here we are testing if the constructor recives in the value utf8 values.</p>
+	 * <p>Here we are testing if the constructor receives in the value utf8 values.</p>
 	 *
 	 */
 	public void testRdnString011(){
@@ -564,7 +564,7 @@
 	}
 	
 	/**
-	 * <p>Here we are testing if the constructor recives in the value an ascii value.</p>
+	 * <p>Here we are testing if the constructor receives in the value an ascii value.</p>
 	 *
 	 */
 	public void testRdnString012(){
@@ -582,7 +582,7 @@
 	}
 	
 	/**
-	 * <p>Here we are testing if the constructor recives in the value ascii values.</p>
+	 * <p>Here we are testing if the constructor receives in the value ascii values.</p>
 	 *
 	 */
 	public void testRdnString013(){
@@ -612,7 +612,7 @@
 	
 	
 	/**
-	 * <p>Here we are testing if the constructor recives an especial character in the type.</p>
+	 * <p>Here we are testing if the constructor receives an especial character in the type.</p>
 	 *
 	 */
 	public void testRdnString014() {
@@ -631,7 +631,7 @@
 	}
 	
 	/**
-	 * <p>Here we are testing if the constructor recives an especial character in the value.</p>
+	 * <p>Here we are testing if the constructor receives an especial character in the value.</p>
 	 *
 	 */
 	public void testRdnString015() {
@@ -652,7 +652,7 @@
 	}
 	
 	/**
-	 * <p>Here we are testing if the constructor can recive an utf8 up to 7e</p>
+	 * <p>Here we are testing if the constructor can receive an utf8 up to 7e</p>
 	 *
 	 */
 	public void testRdnString016(){
@@ -669,7 +669,7 @@
 	}
 	
 	/**
-	 * <p>Here we are testing if the constructor can recive a multivalue.</p> 
+	 * <p>Here we are testing if the constructor can receive a multivalue.</p> 
 	 *
 	 */
 	public void testRdnString017(){
@@ -730,7 +730,7 @@
 	
 	
 	/**
-	 * <p>Here we are testing if the constructor can recive a multivalue between '"'.</p> 
+	 * <p>Here we are testing if the constructor can receive a multivalue between '"'.</p> 
 	 *
 	 */
 	public void testRdnString018(){
@@ -763,7 +763,7 @@
 	}
 	
 	/**
-	 * <p>Here we are testing if the constructor can recive a multivalue between '"'.</p> 
+	 * <p>Here we are testing if the constructor can receive a multivalue between '"'.</p> 
 	 *
 	 */
 	public void testRdnString019(){
@@ -853,7 +853,7 @@
 	}
 	
 	/**
-	 * <p>Here we are testing if the constructor recives combinations of bytes arrays.</p>
+	 * <p>Here we are testing if the constructor receives combinations of bytes arrays.</p>
 	 *
 	 */
 	public void testBytes(){

Modified: harmony/enhanced/classlib/trunk/modules/jndi/src/test/java/org/apache/harmony/jndi/tests/javax/naming/ldap/whitebox/TestControlFactoryWhiteBoxDevelopment.java
URL: http://svn.apache.org/viewvc/harmony/enhanced/classlib/trunk/modules/jndi/src/test/java/org/apache/harmony/jndi/tests/javax/naming/ldap/whitebox/TestControlFactoryWhiteBoxDevelopment.java?rev=587970&r1=587969&r2=587970&view=diff
==============================================================================
--- harmony/enhanced/classlib/trunk/modules/jndi/src/test/java/org/apache/harmony/jndi/tests/javax/naming/ldap/whitebox/TestControlFactoryWhiteBoxDevelopment.java (original)
+++ harmony/enhanced/classlib/trunk/modules/jndi/src/test/java/org/apache/harmony/jndi/tests/javax/naming/ldap/whitebox/TestControlFactoryWhiteBoxDevelopment.java Wed Oct 24 12:12:24 2007
@@ -32,8 +32,8 @@
 
 /**
  * <p>This class test is made to test all cases of package where the coverage was not 100%.</p>
- * <p>We are gonna find here a lot cases from diferent classes, notice here that the conventional structure
- * followed in the rest of the proyect is applied  here.</p>
+ * <p>We are going to find here a lot cases from different classes, notice here that the conventional structure
+ * followed in the rest of the project is applied  here.</p>
  * 
  */
 public class TestControlFactoryWhiteBoxDevelopment extends TestCase {
@@ -55,7 +55,7 @@
 
 	/**
 	 * <p>Test method for 'javax.naming.ldap.ControlFactory.getControlInstance(Control)'</p>
-	 * <p>Here we are gonna test if we can get an instance with the controls sended.</p>
+	 * <p>Here we are going to test if we can get an instance with the controls sended.</p>
 	 */
 	public void testGetControlInstanceControl() {
 

Modified: harmony/enhanced/classlib/trunk/modules/jndi/src/test/java/org/apache/harmony/jndi/tests/javax/naming/ldap/whitebox/TestInitialLdapContextWhiteBoxDevelopment.java
URL: http://svn.apache.org/viewvc/harmony/enhanced/classlib/trunk/modules/jndi/src/test/java/org/apache/harmony/jndi/tests/javax/naming/ldap/whitebox/TestInitialLdapContextWhiteBoxDevelopment.java?rev=587970&r1=587969&r2=587970&view=diff
==============================================================================
--- harmony/enhanced/classlib/trunk/modules/jndi/src/test/java/org/apache/harmony/jndi/tests/javax/naming/ldap/whitebox/TestInitialLdapContextWhiteBoxDevelopment.java (original)
+++ harmony/enhanced/classlib/trunk/modules/jndi/src/test/java/org/apache/harmony/jndi/tests/javax/naming/ldap/whitebox/TestInitialLdapContextWhiteBoxDevelopment.java Wed Oct 24 12:12:24 2007
@@ -30,8 +30,8 @@
 
 /**
  * <p>This class test is made to test all cases of package where the coverage was not 100%.</p>
- * <p>We are gonna find here a lot cases from diferent classes, notice here that the conventional structure
- * followed in the rest of the proyect is applied  here.</p>
+ * <p>We are going to find here a lot cases from different classes, notice here that the conventional structure
+ * followed in the rest of the project is applied  here.</p>
  * 
  */
 public class TestInitialLdapContextWhiteBoxDevelopment extends TestCase {

Modified: harmony/enhanced/classlib/trunk/modules/jndi/src/test/java/org/apache/harmony/jndi/tests/javax/naming/ldap/whitebox/TestLdapNameWhiteBoxDevelopment.java
URL: http://svn.apache.org/viewvc/harmony/enhanced/classlib/trunk/modules/jndi/src/test/java/org/apache/harmony/jndi/tests/javax/naming/ldap/whitebox/TestLdapNameWhiteBoxDevelopment.java?rev=587970&r1=587969&r2=587970&view=diff
==============================================================================
--- harmony/enhanced/classlib/trunk/modules/jndi/src/test/java/org/apache/harmony/jndi/tests/javax/naming/ldap/whitebox/TestLdapNameWhiteBoxDevelopment.java (original)
+++ harmony/enhanced/classlib/trunk/modules/jndi/src/test/java/org/apache/harmony/jndi/tests/javax/naming/ldap/whitebox/TestLdapNameWhiteBoxDevelopment.java Wed Oct 24 12:12:24 2007
@@ -37,8 +37,8 @@
 
 /**
  * <p>This class test is made to test all cases of package where the coverage was not 100%.</p>
- * <p>We are gonna find here a lot cases from diferent classes, notice here that the conventional structure
- * followed in the rest of the proyect is applied  here.</p>
+ * <p>We are going to find here a lot cases from different classes, notice here that the conventional structure
+ * followed in the rest of the project is applied  here.</p>
  * 
  */
 public class TestLdapNameWhiteBoxDevelopment extends TestCase {

Modified: harmony/enhanced/classlib/trunk/modules/jndi/src/test/java/org/apache/harmony/jndi/tests/javax/naming/ldap/whitebox/TestLdapReferralException.java
URL: http://svn.apache.org/viewvc/harmony/enhanced/classlib/trunk/modules/jndi/src/test/java/org/apache/harmony/jndi/tests/javax/naming/ldap/whitebox/TestLdapReferralException.java?rev=587970&r1=587969&r2=587970&view=diff
==============================================================================
--- harmony/enhanced/classlib/trunk/modules/jndi/src/test/java/org/apache/harmony/jndi/tests/javax/naming/ldap/whitebox/TestLdapReferralException.java (original)
+++ harmony/enhanced/classlib/trunk/modules/jndi/src/test/java/org/apache/harmony/jndi/tests/javax/naming/ldap/whitebox/TestLdapReferralException.java Wed Oct 24 12:12:24 2007
@@ -28,8 +28,8 @@
 
 /**
  * <p>This class test is made to test all cases of package where the coverage was not 100%.</p>
- * <p>We are gonna find here a lot cases from diferent classes, notice here that the conventional structure
- * followed in the rest of the proyect is applied  here.</p>
+ * <p>We are going to find here a lot cases from different classes, notice here that the conventional structure
+ * followed in the rest of the project is applied  here.</p>
  * 
  */
 public class TestLdapReferralException extends TestCase {
@@ -50,7 +50,7 @@
 	}
 
 	/**
-	 * Here we are testing if this method recives a string a creates a not null object.
+	 * Here we are testing if this method receives a string a creates a not null object.
 	 *
 	 */
 	public void testLdapReferralExceptionString(){

Modified: harmony/enhanced/classlib/trunk/modules/jndi/src/test/java/org/apache/harmony/jndi/tests/javax/naming/ldap/whitebox/TestRdnWhiteBoxDevelopment.java
URL: http://svn.apache.org/viewvc/harmony/enhanced/classlib/trunk/modules/jndi/src/test/java/org/apache/harmony/jndi/tests/javax/naming/ldap/whitebox/TestRdnWhiteBoxDevelopment.java?rev=587970&r1=587969&r2=587970&view=diff
==============================================================================
--- harmony/enhanced/classlib/trunk/modules/jndi/src/test/java/org/apache/harmony/jndi/tests/javax/naming/ldap/whitebox/TestRdnWhiteBoxDevelopment.java (original)
+++ harmony/enhanced/classlib/trunk/modules/jndi/src/test/java/org/apache/harmony/jndi/tests/javax/naming/ldap/whitebox/TestRdnWhiteBoxDevelopment.java Wed Oct 24 12:12:24 2007
@@ -36,8 +36,8 @@
  * not 100%.
  * </p>
  * <p>
- * We are gonna find here a lot cases from diferent classes, notice here that
- * the conventional structure followed in the rest of the proyect is applied
+ * We are going to find here a lot cases from different classes, notice here that
+ * the conventional structure followed in the rest of the project is applied
  * here.
  * </p>
  * 
@@ -53,7 +53,7 @@
      * Test method for 'javax.naming.ldap.Rdn.Rdn(String)'
      * </p>
      * <p>
-     * Here we are testing if the constructor can recive several multivalued
+     * Here we are testing if the constructor can receive several multivalued
      * types.
      * </p>
      * <p>
@@ -80,7 +80,7 @@
      * Test method for 'javax.naming.ldap.Rdn.Rdn(String)'
      * </p>
      * <p>
-     * Here we are testing if the constructor can recive the special character
+     * Here we are testing if the constructor can receive the special character
      * "\".
      * </p>
      * <p>
@@ -100,7 +100,7 @@
      * Test method for 'javax.naming.ldap.Rdn.Rdn(String)'
      * </p>
      * <p>
-     * Here we are testing if the constructor can recive the special character
+     * Here we are testing if the constructor can receive the special character
      * "+".
      * </p>
      * <p>
@@ -118,7 +118,7 @@
      * Test method for 'javax.naming.ldap.Rdn.Rdn(String)'
      * </p>
      * <p>
-     * Here we are testing if the constructor can recive the special character
+     * Here we are testing if the constructor can receive the special character
      * "#".
      * </p>
      * <p>
@@ -134,7 +134,7 @@
      * Test method for 'javax.naming.ldap.Rdn.equals(Rdn)'
      * </p>
      * <p>
-     * Here we are testing if the method can recive a Rdn.
+     * Here we are testing if the method can receive a Rdn.
      * </p>
      * <p>
      * The expected result is that two rdns must be the same.
@@ -151,7 +151,7 @@
      * Test method for 'javax.naming.ldap.Rdn.equals(Rdn)'
      * </p>
      * <p>
-     * Here we are testing if the method can recive a Rdn.
+     * Here we are testing if the method can receive a Rdn.
      * </p>
      * <p>
      * The expected result is that two rdns must be the same.
@@ -168,7 +168,7 @@
      * Test method for 'javax.naming.ldap.Rdn.equals(Rdn)'
      * </p>
      * <p>
-     * Here we are testing if the method can recive a Rdn.
+     * Here we are testing if the method can receive a Rdn.
      * </p>
      * <p>
      * The expected result is that two rdns must be the same.
@@ -186,7 +186,7 @@
      * Test method for 'javax.naming.ldap.Rdn.equals(Rdn)'
      * </p>
      * <p>
-     * Here we are testing if the method can recive a Rdn.
+     * Here we are testing if the method can receive a Rdn.
      * </p>
      * <p>
      * The expected result is that two rdns must be the same.
@@ -228,7 +228,7 @@
      * Test method for 'javax.naming.ldap.Rdn.equals(Rdn)'
      * </p>
      * <p>
-     * Here we are testing if the method can recive a Rdn with a different
+     * Here we are testing if the method can receive a Rdn with a different
      * array.
      * </p>
      * <p>
@@ -485,7 +485,7 @@
 
     /**
      * <p>
-     * Test methdo to test if the constructor can recive the correct lenght to a
+     * Test method to test if the constructor can receive the correct length to a
      * byte array.
      * </p>
      * 

Modified: harmony/enhanced/classlib/trunk/modules/jndi/src/test/java/org/apache/harmony/jndi/tests/javax/naming/spi/mock/ldap/MockInitialLdapContext.java
URL: http://svn.apache.org/viewvc/harmony/enhanced/classlib/trunk/modules/jndi/src/test/java/org/apache/harmony/jndi/tests/javax/naming/spi/mock/ldap/MockInitialLdapContext.java?rev=587970&r1=587969&r2=587970&view=diff
==============================================================================
--- harmony/enhanced/classlib/trunk/modules/jndi/src/test/java/org/apache/harmony/jndi/tests/javax/naming/spi/mock/ldap/MockInitialLdapContext.java (original)
+++ harmony/enhanced/classlib/trunk/modules/jndi/src/test/java/org/apache/harmony/jndi/tests/javax/naming/spi/mock/ldap/MockInitialLdapContext.java Wed Oct 24 12:12:24 2007
@@ -64,7 +64,7 @@
 	Control[] last=null;
 	
 	/**
-	 * <p>This method retrives the properties.</p>
+	 * <p>This method retrieves the properties.</p>
 	 */
 	public Hashtable getProps(){
 		return env;
@@ -126,7 +126,7 @@
 	}
 	
 	/**
-	 * <p>This methdo retrives the connection controls.</p>
+	 * <p>This method retrieves the connection controls.</p>
 	 * @return The connection controls.
 	 */
 	public Control[] getConnectControls() throws NamingException {

Modified: harmony/enhanced/classlib/trunk/modules/jndi/src/test/java/org/apache/harmony/jndi/tests/javax/naming/spi/mock/ldap/MockUnsolicitedNotification.java
URL: http://svn.apache.org/viewvc/harmony/enhanced/classlib/trunk/modules/jndi/src/test/java/org/apache/harmony/jndi/tests/javax/naming/spi/mock/ldap/MockUnsolicitedNotification.java?rev=587970&r1=587969&r2=587970&view=diff
==============================================================================
--- harmony/enhanced/classlib/trunk/modules/jndi/src/test/java/org/apache/harmony/jndi/tests/javax/naming/spi/mock/ldap/MockUnsolicitedNotification.java (original)
+++ harmony/enhanced/classlib/trunk/modules/jndi/src/test/java/org/apache/harmony/jndi/tests/javax/naming/spi/mock/ldap/MockUnsolicitedNotification.java Wed Oct 24 12:12:24 2007
@@ -31,7 +31,7 @@
 
 /**
  * <p>Implementation of the interfaces UnsolicitedNotificationListener and UnsolicitedNotification. This class has the intention of
- * give us a notifiction or a listener to test another classes.</p> 
+ * give us a notification or a listener to test another classes.</p> 
  *
  */
 public class MockUnsolicitedNotification implements
@@ -41,7 +41,7 @@
 	 */
 	private static final long serialVersionUID = 1L;
 	/**
 	 * <p>This flag has the intention of give us a way to know if a notification was recived.</p>
 	 */
 	private boolean flag;
 
@@ -51,11 +51,11 @@
 	 */
 	public MockUnsolicitedNotification() {
 		super();
-		flag=false;//Flag to know if a the notification was recived.
+		flag=false;//Flag to know if a the notification was received.
 		
 	}
 	/**
 	 * <p>Here we recived the notification, so we set the flag true.</p>
 	 */
 	public void notificationReceived(UnsolicitedNotificationEvent arg0) {
 		flag=true;
@@ -63,7 +63,7 @@
 	}
 
 	/**
 	 * <p>Method to see if the notitfication was recived.</p>
 	 * @return The flag of the notification.
 	 */
 	public boolean getFlag(){
@@ -41,7 +41,7 @@
 	private static final long serialVersionUID = 1L;
 	/**
-	 * <p>This flag has the intention of give us a way to know if a notification was recived.</p>
+	 * <p>This flag has the intention of give us a way to know if a notification was received.</p>
 	 */
 	private boolean flag;
@@ -51,11 +51,11 @@
 	}
 	/**
-	 * <p>Here we recived the notification, so we set the flag true.</p>
+	 * <p>Here we received the notification, so we set the flag true.</p>
 	 */
 	public void notificationReceived(UnsolicitedNotificationEvent arg0) {
@@ -63,7 +63,7 @@
 
 	/**
-	 * <p>Method to see if the notitfication was recived.</p>
+	 * <p>Method to see if the notification was received.</p>
 	 * @return The flag of the notification.
 	 */